@@ -292,6 +292,7 @@ showVal :: Stringable a => SEnv a -> SElem a -> a
 showVal snv se = case se of
                    STR x  -> stEncode x
                    BS  x  -> stEncodeBS x
+                   TXT x  -> stEncodeText x
                    LI xs  -> joinUpWith showVal xs
                    SM sm  -> joinUpWith showAssoc $ M.assocs sm
                    STSH x -> stEncode (format x)
@@ -301,8 +302,9 @@ showVal snv se = case se of
     where format = maybe stshow . stfshow <*> optLookup "format" $ snv
           joinUpWith f xs = mconcatMap' snv xs (f snv)
           showAssoc e (k,v) = stEncode (k ++ ": ") `mlabel` showVal e v
-          stEncode   = senc snv . stFromString
-          stEncodeBS = senc snv . stFromByteString
+          stEncode     = senc snv . stFromString
+          stEncodeBS   = senc snv . stFromByteString
+          stEncodeText = senc snv . stFromText
 
 showStr :: Stringable a => String -> SEnv a -> a
 showStr = const . stFromString
@@ -349,7 +351,7 @@ escapedStr' chs = dropTrailingBr <$> escapedStr chs
   The Grammar
 --------------------------------------------------------------------}
 myConcat :: Stringable a => [SEnv a -> a] -> (SEnv a -> a)
-myConcat xs a = smconcat $ map ($ a) xs
+myConcat xs a = mconcatMap xs ($ a)
 
 
 -- | if p is true, stmpl can fail gracefully, false it dies hard.
@@ -415,7 +417,10 @@ getProp :: Stringable a => [SEnv a -> SElem a] -> SElem a -> SEnv a -> SElem a
 getProp (p:ps) (SM mp) env =
   case M.lookup (stToString . showVal env $ p env) mp of
     Just prop -> getProp ps prop env
-    Nothing -> SNull
+    Nothing -> case optLookup "throwException" env of
+                 Just _ -> C.throw . NoAttrib $ "yeek" --intercalate "." . map showIt $ (p:ps)
+                 Nothing -> SNull
+  --where showIt x = stToString . showVal env $ x env
 getProp (_:_) _ _ = SNull
 getProp _ se _ = se
 
